@@ -1099,6 +1099,17 @@ def set_active_tty(ttynum):
     """
     Установить активный терминал
     """
-    chvt = getProgPath("/usr/bin/chvt2")
+    chvt = getProgPath("/usr/bin/chvt")
     if chvt:
         os.system('chvt %d &>/dev/null' % ttynum)
+
+def get_active_tty():
+    """
+    Получить активный терминал
+    """
+    getvt = getProgPath("/usr/bin/fgconsole")
+    if getvt:
+        p = process(getvt)
+        if p.success():
+            return p.read().strip()
+    return None
